@@ -421,7 +421,7 @@ class Collection(BaseCollection):
             href_mapper = HrefMapper(content=etesync_item._cache_obj, href=href)
             href_mapper.save(force_insert=True)
 
-        return self._get(href)
+        return (self._get(href), item)
 
     def delete(self, href=None):
         """Delete an item.
@@ -501,7 +501,7 @@ class Storage(BaseStorage):
         self._etesync_user_lock = threading.RLock()
         super().__init__(configuration)
 
-    def discover(self, path, depth="0", child_context_manager = None, user_groups = set([])):
+    def discover(self, path, depth="0", child_context_manager=None, user_groups=set([])):
         """Discover a list of collections under the given ``path``.
 
         If ``depth`` is "0", only the actual object under ``path`` is
@@ -605,7 +605,7 @@ class Storage(BaseStorage):
         raise NotImplementedError
 
     @contextmanager
-    def acquire_lock(self, mode, user=None):
+    def acquire_lock(self, mode, user=None, *args, **kwargs):
         """Set a context manager to lock the whole storage.
 
         ``mode`` must either be "r" for shared access or "w" for exclusive
